@@ -19,4 +19,5 @@ SO_API_VERSION = "v7"
 VID_URL     = "https://vid.api.simpledemo.onap.org:30200"
 VID_API_VERSION = "/vid"
 CLAMP_URL   = "https://clamp.api.simpledemo.onap.org:30258"
-VES_URL     = "https://ves.api.simpledemo.onap.org:30417"
+VES_URL = "http://ves.api.simpledemo.onap.org:30417"
+DMAAP_URL = "http://dmaap.api.simpledemo.onap.org:3904"
